/**
 * This export is a variant of the quickjs WASM library:
 * ### [@jitl/quickjs-browser-release-asyncify-singlefile](https://github.com/justjake/quickjs-emscripten/blob/main/doc/packages/@jitl/quickjs-browser-release-asyncify-singlefile/README.md)
 *
 * ESModule for browsers or browser-like environments
 *
 * | Variable            |    Setting                     |    Description    |
 * | --                  | --                             | --                |
 * | releaseMode         | release | Optimized for performance; use when building/deploying your application. |
 * | syncMode            | asyncify | Build run through the ASYNCIFY WebAssembly transform. Larger and slower. Allows synchronous calls from the WASM runtime to async functions on the host. The extra magic makes this variant slower than sync variants. Note that both variants support regular async functions. Only adopt ASYNCIFY if you need to! |
 * | moduleSystem        | esm | This variant exports an ESModule, which is standardized for browsers and more modern browser-like environments. It cannot be imported from CommonJS without shenanigans. |
 * | emscriptenInclusion | singlefile | The WASM runtime is included directly in the JS file. Use if you run into issues with missing .wasm files when building or deploying your app. |
 *
 */
declare const variant: {
    readonly type: "async";
    readonly importFFI: () => Promise<typeof import("./ffi.js").QuickJSAsyncFFI | (new (module: import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule) => import("@jitl/quickjs-ffi-types").QuickJSAsyncFFI)>;
    readonly importModuleLoader: () => Promise<import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule> | {
        default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule>;
    } | {
        default: {
            default: import("@jitl/quickjs-ffi-types").EmscriptenModuleLoader<import("@jitl/quickjs-ffi-types").QuickJSAsyncEmscriptenModule>;
        };
    }>;
};
export default variant;
